% Wyznacza jakosc rodziny konceptow decyzyjnych.
%
% [jakosc] = roughInfo(A, widok)
%
% Parametry:  
%        A - macierz komorkowa danych
%        widok - czy wywietla informacje w konsoli (1 - tak, 0 - nie)
%
% Zwraca jakosc przyblizenia rodziny konceptow decyzyjnych.
%
function [jakosc] = roughInfo(A, widok)

if nargin==1
    widok = 0;
end

D = A{1};

nr_w = size(D,2) - 1;  % ilosc atrybutow warunkowych
DW = D(:,1:nr_w);      % atrybuty warunkowe
DD = D(:,nr_w + 1);    % atrybuty decyzyjne 

[DW1, DW_i, DW_j] = unique(DW,'rows');
if widok
    disp('Elementarne zbiory warunkowe:')
    for i = 1:size(DW1,1)
        s0 = sprintf('(%d)',i);
        s1 = '';
        for j = 1:size(DW1,2)
            s1 = [s1 sprintf('%10s',A{2}{j}{DW1(i,j)} )];
        end
        s2 = sprintf('%5d',find(DW_j == i));
        disp([s0 ' [' s1 ' ] -- probki nr: ' s2]);     
    end
    disp(' ');
end

[DD1, DD_i, DD_j] = unique(DD,'rows');
if widok
    disp('Elementarne zbiory decyzyjne:')
    for i = 1:size(DD1,1)
        s0 = sprintf('(%d)',i);
        s1 = sprintf('%5s',A{2}{nr_w+1}{i});
        s2 = sprintf('%5d',find(DD_j == i));
        disp([s0 ' [' s1 ' ] -- probki nr: ' s2]);     
    end
    disp(' ');
end

for i = 1:size(DD1,1)
    if widok
        disp(repmat('-',1,80));
        s = sprintf('Koncept decyzyjny: %s', A{2}{nr_w+1}{i}); disp(s);
        disp(repmat('-',1,80));
    end
    
    v = [];
    for j = 1:size(DW1,1)
         pr = find(DW_j == j);
         if all(DD(pr)==DD1(i,:)) v = [v pr']; end
    end

    DD_RS{i,1} = sort(v);
    if widok
        s2 = sprintf('%5d',DD_RS{i,1});
        disp(['Dolne przyblizenie: ' s2]);
    end
    
    v = [];
    for j = 1:size(DW1,1)
         pr = find(DW_j == j);
         if any(DD(pr)==DD1(i,:)) v = [v pr']; end
    end
    DD_RS{i,2} = sort(v);

    if widok
        DD_RS{i,3} = setdiff(DD_RS{i,2}, DD_RS{i,1});
        s2 = sprintf('%5d', DD_RS{i,2});
        disp(['Gorne przyblizenie: ' s2]);
        s2 = sprintf('%5d', DD_RS{i,3});
        disp(['Region graniczny:   ' s2]);
        s = sprintf('Dokladnosc przyblizenia konceptu: %g', length(DD_RS{i,1})/length(DD_RS{i,2})); disp(s);
    end
end

sd = 0;
sg = 0;
for i = 1:size(DD1,1)
    sd = sd + length(DD_RS{i,1});
    sg = sg + length(DD_RS{i,2});
end

jakosc = sd/size(D,1);
if widok
    disp(repmat('-',1,80));
    dokladnosc = sd/sg;
    s = sprintf('Dokladnosc przyblizenia rodziny konceptow decyzyjnych: %g', dokladnosc); disp(s);
    s = sprintf('Jakosc przyblizenia rodziny konceptow decyzyjnych: %g', jakosc); disp(s);
    disp(repmat('-',1,80));
end

